@@ -58,7 +58,7 @@ class Api(object):
             params=params,
             auth=self.event.get('requestContext', {}).get('authorizer', None) or {},
             headers=self.event.get('headers', None),
-            route=self.event.get('path', None)
+            route=self.event.get('resource', None)
         )
 
     def request(self):
